<?php

namespace Superrobota\Softskill\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Superrobota\Softskill\Http\Requests\SoftSkillsRequest;
use Superrobota\Softskill\Interfaces\SoftSkillsRepositoryInterface;
use Superrobota\Softskill\Models\SoftSkills;

/**
 * Resource controller class for soft_skills.
 */
class SoftSkillsResourceController extends BaseController
{

    /**
     * Initialize soft_skills resource controller.
     *
     * @param type SoftSkillsRepositoryInterface $soft_skills
     *
     * @return null
     */
    public function __construct(SoftSkillsRepositoryInterface $soft_skills)
    {
        parent::__construct();
        $this->repository = $soft_skills;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Superrobota\Softskill\Repositories\Criteria\SoftSkillsResourceCriteria::class);
    }

    /**
     * Display a list of soft_skills.
     *
     * @return Response
     */
    public function index(SoftSkillsRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Superrobota\Softskill\Repositories\Presenter\SoftSkillsPresenter::class)
                ->$function();
        }

        $soft_skills = $this->repository->paginate();

        return $this->response->title(trans('softskill::soft_skills.names'))
            ->view('softskill::soft_skills.index', true)
            ->data(compact('soft_skills'))
            ->output();
    }

    /**
     * Display soft_skills.
     *
     * @param Request $request
     * @param Model   $soft_skills
     *
     * @return Response
     */
    public function show(SoftSkillsRequest $request, SoftSkills $soft_skills)
    {

        if ($soft_skills->exists) {
            $view = 'softskill::soft_skills.show';
        } else {
            $view = 'softskill::soft_skills.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('softskill::soft_skills.name'))
            ->data(compact('soft_skills'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new soft_skills.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(SoftSkillsRequest $request)
    {

        $soft_skills = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('softskill::soft_skills.name')) 
            ->view('softskill::soft_skills.create', true) 
            ->data(compact('soft_skills'))
            ->output();
    }

    /**
     * Create new soft_skills.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(SoftSkillsRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $soft_skills                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('softskill::soft_skills.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('softskill/soft_skills/' . $soft_skills->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/softskill/soft_skills'))
                ->redirect();
        }

    }

    /**
     * Show soft_skills for editing.
     *
     * @param Request $request
     * @param Model   $soft_skills
     *
     * @return Response
     */
    public function edit(SoftSkillsRequest $request, SoftSkills $soft_skills)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('softskill::soft_skills.name'))
            ->view('softskill::soft_skills.edit', true)
            ->data(compact('soft_skills'))
            ->output();
    }

    /**
     * Update the soft_skills.
     *
     * @param Request $request
     * @param Model   $soft_skills
     *
     * @return Response
     */
    public function update(SoftSkillsRequest $request, SoftSkills $soft_skills)
    {
        try {
            $attributes = $request->all();

            $soft_skills->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('softskill::soft_skills.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('softskill/soft_skills/' . $soft_skills->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('softskill/soft_skills/' . $soft_skills->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the soft_skills.
     *
     * @param Model   $soft_skills
     *
     * @return Response
     */
    public function destroy(SoftSkillsRequest $request, SoftSkills $soft_skills)
    {
        try {

            $soft_skills->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('softskill::soft_skills.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('softskill/soft_skills/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('softskill/soft_skills/' . $soft_skills->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple soft_skills.
     *
     * @param Model   $soft_skills
     *
     * @return Response
     */
    public function delete(SoftSkillsRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('softskill::soft_skills.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('softskill/soft_skills'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/softskill/soft_skills'))
                ->redirect();
        }

    }

    /**
     * Restore deleted soft_skills.
     *
     * @param Model   $soft_skills
     *
     * @return Response
     */
    public function restore(SoftSkillsRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('softskill::soft_skills.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/softskill/soft_skills'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/softskill/soft_skills/'))
                ->redirect();
        }

    }

}
